"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.FlexIcon = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames2 = _interopRequireDefault(require("classnames"));

var R = _interopRequireWildcard(require("ramda"));

var _styles = require("@material-ui/styles");

require("mdi/css/materialdesignicons.min.css");

var _styles2 = require("@material-ui/core/styles");

var _Icon = _interopRequireDefault(require("@material-ui/core/Icon"));

var _transforms = require("../transforms");

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj["default"] = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var stringToThemeColor = function stringToThemeColor(string, theme) {
  if (string === 'inherit') return 'inherit';
  if (string === 'secondary') return theme.palette.secondary.main;
  if (string === 'primary') return theme.palette.primary.main;
  if (string === 'action') return theme.palette.action.active;
  if (string === 'disabled') return theme.palette.action.disabled;
  if (string === 'error') return theme.palette.error.main;
  return string;
};

var clampIconSize = R.cond([[(0, _transforms.between)(0, 21), R.always(18)], [(0, _transforms.between)(21, 30), R.always(24)], [(0, _transforms.between)(30, 42), R.always(36)], [(0, _transforms.between)(42, 100000), R.always(48)]]);
var sizeToNumber = {
  sm: 18,
  md: 24,
  lg: 36,
  xl: 48
};

var sizeToNum = function sizeToNum(size) {
  return typeof size === 'string' ? sizeToNumber[size] || sizeToNumber.xl : size;
}; // const sizeToPx = size => `${sizeToNum(size)}px`;


var propTypes = {
  children: _propTypes["default"].node,
  theme: _propTypes["default"].objectOf(_propTypes["default"].any).isRequired,
  style: _propTypes["default"].objectOf(_propTypes["default"].any),
  icon: _propTypes["default"].string,
  className: _propTypes["default"].string,
  size: _propTypes["default"].oneOfType([_propTypes["default"].string, _propTypes["default"].number]),
  color: _propTypes["default"].string // inherit, secondary, primary, action, disabled or error

};
var defaultProps = {
  children: undefined,
  color: undefined,
  className: '',
  size: 24,
  style: {},
  icon: undefined
};
var useStyles = (0, _styles.makeStyles)(function () {
  return {
    mdicon: function mdicon(_ref) {
      var size = _ref.size;
      return {
        '&::before': {
          // fontSize: 24,
          // fontSize: `${size}px !important`,
          fontSize: "".concat(sizeToNum(size), "px !important")
        }
      };
    },
    '&.mdi-48px::before': function mdi48pxBefore(_ref2) {
      var size = _ref2.size;
      return {
        fontSize: "".concat(sizeToNum(size), "px !important")
      };
    },
    '.mdi-48px.mdi::before': function mdi48pxMdiBefore(_ref3) {
      var size = _ref3.size;
      return {
        fontSize: "".concat(sizeToNum(size), "px !important")
      };
    },
    '&.mdi-48px.mdi::before': function mdi48pxMdiBefore(_ref4) {
      var size = _ref4.size;
      return {
        fontSize: "".concat(sizeToNum(size), "px !important")
      };
    }
  };
});

var FlexIconC = _react["default"].memo(function (_ref5) {
  var icon = _ref5.icon,
      style = _ref5.style,
      theme = _ref5.theme,
      color = _ref5.color,
      size = _ref5.size,
      children = _ref5.children,
      className = _ref5.className;
  var classes = useStyles(); // console.log('FLEXICON render:', icon, color, size, children);

  var iconStr = (children || icon).trim();
  var mdi = iconStr.startsWith('mdi-');
  var sizeNumber = sizeToNum(size); // console.log('FlexIcon:', size, sizeNumber);
  // const iconSize = typeof size === 'number' ? `${size}px` : sizeToPx(size);

  if (mdi) {
    var _classnames;

    return _react["default"].createElement("i", {
      style: _objectSpread({
        color: stringToThemeColor(color, theme),
        lineHeight: "".concat(sizeNumber, "px"),
        fontSize: "".concat(sizeNumber, "px"),
        height: sizeNumber,
        width: sizeNumber
      }, style),
      className: (0, _classnames2["default"])((_classnames = {
        mdi: true,
        'mdi-48px': true
      }, _defineProperty(_classnames, iconStr, true), _defineProperty(_classnames, className, !!className), _defineProperty(_classnames, classes.mdicon, true), _classnames))
    });
  }

  var inlineStyle = _objectSpread({
    fontSize: sizeNumber
  }, style);

  if (color && (color.startsWith('#') || color.startsWith('rgb'))) {
    inlineStyle.color = color;
    return _react["default"].createElement(_Icon["default"], {
      style: inlineStyle,
      className: className
    }, iconStr);
  }

  return _react["default"].createElement(_Icon["default"], {
    style: inlineStyle,
    color: color,
    className: className
  }, iconStr);
});

FlexIconC.propTypes = propTypes;
FlexIconC.defaultProps = defaultProps;
var FlexIcon = (0, _styles2.withStyles)(function () {
  return {};
}, {
  withTheme: true
})(FlexIconC);
exports.FlexIcon = FlexIcon;